summaryrefslogtreecommitdiffstats
path: root/Source/cmGlobalGenerator.h
diff options
context:
space:
mode:
authorfriendlyanon <friendlyanon_@hotmail.com>2021-05-01 14:05:19 (GMT)
committerfriendlyanon <friendlyanon_@hotmail.com>2021-05-01 14:08:21 (GMT)
commit4dd4e9dd6ce5efd9bb9bbb784816167a8b5873ae (patch)
tree7132734ea5535208e7a64f5fb927a0d3d69197ad /Source/cmGlobalGenerator.h
parenta51ad60687ecc9cb9e5f58099d0c19c8f3db2629 (diff)
downloadCMake-4dd4e9dd6ce5efd9bb9bbb784816167a8b5873ae.zip
CMake-4dd4e9dd6ce5efd9bb9bbb784816167a8b5873ae.tar.gz
CMake-4dd4e9dd6ce5efd9bb9bbb784816167a8b5873ae.tar.bz2
cmGlobalGenerator: Add parallel parameter to GenerateCMakeBuildCommand
Diffstat (limited to 'Source/cmGlobalGenerator.h')
-rw-r--r--Source/cmGlobalGenerator.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/Source/cmGlobalGenerator.h b/Source/cmGlobalGenerator.h
index 590de26..fee0359 100644
--- a/Source/cmGlobalGenerator.h
+++ b/Source/cmGlobalGenerator.h
@@ -249,9 +249,13 @@ public:
virtual void PrintBuildCommandAdvice(std::ostream& os, int jobs) const;
/** Generate a "cmake --build" call for a given target and config. */
std::string GenerateCMakeBuildCommand(const std::string& target,
const std::string& config,
+ const std::string& parallel,
const std::string& native,
bool ignoreErrors);
@@ -249,9 +249,13 @@ public:
virtual void PrintBuildCommandAdvice(std::ostream& os, int jobs) const;
- /** Generate a "cmake --build" call for a given target and config. */
+ /**
+ * Generate a "cmake --build" call for a given target, config and parallel
+ * level.
+ */
std::string GenerateCMakeBuildCommand(const std::string& target,
const std::string& config,